# taupy

## About
`taupy` is a Python 3 package for the study of dialectical structures. It can represent arguments, debates, positions, and can perform operations on these objects, including measurements of agreement, polarisation, but also degrees of justification. `taupy` can also be used to build computer models of dialectical structures, which can be used in agent-based debate simulations.

## Installation
The recommended installation method is to use `pip`:

```
pip install taupy
```

## Contribute & Feedback
Your contributions and feedback are most welcome! Please feel free to open an issue if you found a bug or miss a feature, or a pull request if you want to submit an improvement.

## License
This project is (c) Felix Kopecky, licensed under BSD-3.